@@ -11,6 +11,7 @@
 
 // qt / kde includes
 #include <qcolor.h>
+#include <qcursor.h>
 #include <qevent.h>
 #include <qpainter.h>
 
@@ -76,6 +77,11 @@ AnnotatorEngine::~AnnotatorEngine()
 {
 }
 
+QCursor AnnotatorEngine::cursor() const
+{
+    return Qt::CrossCursor;
+}
+
 SmoothPath::SmoothPath( const QLinkedList<Okular::NormalizedPoint> &points, const QPen &pen )
     : points ( points ), pen ( pen )
 {
